@@ -172,6 +172,13 @@ chrome_print = function(
     if (missing(output) && !file.exists(input))
       output = xfun::with_ext(basename(gsub('[#?].*', '', url)), format)
     output2 = normalizePath(output, mustWork = FALSE)
+    # try to remove the file and throw a clear error if it still exists as it may be locked
+    if (!suppressWarnings(file.remove(output2)) && xfun::file_exists(output2)) {
+      stop(
+        "The file '", output, "' cannot be overwritten",
+        if (format == "pdf") " (may be locked by a PDF reader?)", "."
+      )
+    }
     if (!dir.exists(d <- dirname(output2)) && !dir.create(d, recursive = TRUE)) stop(
       'Cannot create the directory for the output file: ', d
     )
@@ -574,7 +581,7 @@ print_page = function(
         # if a stream handle is received -> callback: command #17 IO.read
         if (is.null(stream_handle <<- msg$result$stream)) {
           writeBin(jsonlite::base64_dec(msg$result$data), output)
-          if (!xfun::isFALSE(outline) && length(toc_infos)) add_outline(output, toc_infos, verbose)
+          if (!isFALSE(outline) && length(toc_infos)) add_outline(output, toc_infos, verbose)
           resolve(output)
           token$done = TRUE
         } else {
@@ -618,7 +625,7 @@ print_page = function(
       },
       {
         # Command #18 received -> callback: add outline & close Chrome
-        if (!xfun::isFALSE(outline) && length(toc_infos)) add_outline(output, toc_infos, verbose)
+        if (!isFALSE(outline) && length(toc_infos)) add_outline(output, toc_infos, verbose)
         resolve(output)
         token$done = TRUE
       }
